import { forwardRef } from 'react';
import PropTypes from 'prop-types';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs';
import { SIZES, INPUT_STATES, INPUT_SHAPES, noop, getClassNames } from '../../config';
import { jsx as _jsx } from "react/jsx-runtime";
var Input = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var disabled = _ref.disabled,
      readOnly = _ref.readOnly,
      hideInput = _ref.hideInput,
      noBorder = _ref.noBorder,
      id = _ref.id,
      name = _ref.name,
      onBlur = _ref.onBlur,
      onFocus = _ref.onFocus,
      placeholder = _ref.placeholder,
      reference = _ref.reference,
      size = _ref.size,
      errorState = _ref.errorState,
      state = _ref.state,
      type = _ref.type,
      value = _ref.value,
      charsSize = _ref.charsSize,
      _ref$tabIndex = _ref.tabIndex,
      tabIndex = _ref$tabIndex === void 0 ? -1 : _ref$tabIndex,
      ariaLabel = _ref.ariaLabel,
      maxLength = _ref.maxLength,
      minLength = _ref.minLength,
      defaultValue = _ref.defaultValue,
      min = _ref.min,
      max = _ref.max,
      step = _ref.step,
      autoComplete = _ref.autoComplete,
      autoFocus = _ref.autoFocus,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? noop : _ref$onChange,
      _ref$onEnter = _ref.onEnter,
      onEnter = _ref$onEnter === void 0 ? noop : _ref$onEnter,
      _ref$onEnterKey = _ref.onEnterKey,
      onEnterKey = _ref$onEnterKey === void 0 ? 'Enter' : _ref$onEnterKey,
      _ref$onKeyDown = _ref.onKeyDown,
      onKeyDown = _ref$onKeyDown === void 0 ? noop : _ref$onKeyDown,
      required = _ref.required,
      pattern = _ref.pattern,
      inputMode = _ref.inputMode,
      shape = _ref.shape;

  var changeHandler = function changeHandler(ev) {
    var _ev$target = ev.target,
        value = _ev$target.value,
        name = _ev$target.name;
    onChange(ev, {
      value: value,
      name: name
    });
  };

  var handleKeyDown = function handleKeyDown(ev) {
    var _ev$target2 = ev.target,
        value = _ev$target2.value,
        name = _ev$target2.name;
    var key = ev.key;
    onKeyDown(ev, {
      value: value,
      name: name
    });
    if (key === onEnterKey) onEnter(ev, {
      value: value,
      name: name
    });
  };

  var className = getClassNames({
    size: size,
    charsSize: charsSize,
    hideInput: hideInput,
    noBorder: noBorder,
    readOnly: readOnly,
    errorState: errorState,
    state: state,
    shape: shape
  });
  return /*#__PURE__*/_jsx("input", {
    className: className,
    tabIndex: tabIndex,
    "aria-label": ariaLabel,
    disabled: disabled,
    readOnly: readOnly,
    id: id,
    name: name,
    onChange: changeHandler,
    onFocus: onFocus,
    onBlur: onBlur,
    onKeyDown: handleKeyDown,
    placeholder: placeholder,
    ref: useMergeRefs.apply(void 0, [reference, forwardedRef].filter(Boolean)),
    type: type,
    value: value,
    size: charsSize,
    defaultValue: defaultValue,
    maxLength: maxLength,
    minLength: minLength,
    max: max,
    min: min,
    step: step,
    autoComplete: autoComplete,
    autoFocus: autoFocus,
    required: required,
    pattern: pattern,
    inputMode: inputMode
  });
});
export default Input;
export { SIZES as inputSizes, INPUT_STATES as inputStates };